pub struct FsVerityDescriptor<'a> { /* private fields */ }Expand description
A descriptor struct for fsverity backed by a pointer slice. It does not own the bytes backing it.
Implementations
Sourceimpl<'a> FsVerityDescriptor<'a>
impl<'a> FsVerityDescriptor<'a>
Sourcepub fn new(
bytes: impl Into<PtrByteSlice<'a>>,
block_size: usize,
) -> Result<Self, Error>
pub fn new( bytes: impl Into<PtrByteSlice<'a>>, block_size: usize, ) -> Result<Self, Error>
Create a descriptor from data that can be converted into a pointer slice.
pub fn digest_len(&self) -> usize
pub fn digest_algorithm(&self) -> HashAlgorithm
pub fn block_size(&self) -> usize
pub fn file_size(&self) -> usize
pub fn root_digest(&self) -> &[u8] ⓘ
pub fn salt(&self) -> &[u8] ⓘ
Sourcepub fn hasher(&self) -> FsVerityHasher
pub fn hasher(&self) -> FsVerityHasher
Return a hasher configured based on this descriptor.